==> greenbone-security-assistant-8.0.0.tar.gz: gsa-8.0.0/gsa/src/gmp/models/report/tlscertificate.js <==
/* Copyright (C) 2017-2019 Greenbone Networks GmbH
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
import 'core-js/fn/object/entries';

import {isDefined} from '../../utils/identity';

import {parseInt} from '../../parser';

class TLSCertificate {
  constructor(fingerprint) {
    this.fingerprint = fingerprint;
    this.ports = [];
  }

  addPort(port) {
    let c_port = parseInt(port);
    if (!isDefined(c_port)) {
      // port wasn't a number
      c_port = port;
    }

    this.ports.push(port);
  }

  copy() {
    const cert = new TLSCertificate(this.fingerprint);
    for (const [key, value] of Object.entries(this)) {
      cert[key] = value;
    }
    return cert;
  }

  get id() {
    return this.ip + ':' + this.port + ':' + this.fingerprint;
  }
}

export default TLSCertificate;

// vim: set ts=2 sw=2 tw=80:

==> greenbone-security-assistant-9.0.0.tar.gz: gsa-9.0.0/gsa/src/gmp/models/report/tlscertificate.js <==
/* Copyright (C) 2017-2019 Greenbone Networks GmbH
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
import 'core-js/features/object/entries';

import {isDefined} from 'gmp/utils/identity';

import {setProperties, parseInt} from 'gmp/parser';

class TLSCertificate {
  constructor() {
    this.ports = [];
  }

  addPort(port) {
    let parsedPort = parseInt(port);
    if (!isDefined(parsedPort)) {
      // port wasn't a number
      parsedPort = port;
    }

    this.ports.push(parsedPort);
  }

  copy() {
    const cert = TLSCertificate.fromElement({fingerprint: this.fingerprint});

    for (const [key, value] of Object.entries(this)) {
      if (key === 'fingerprint') {
        continue;
      }
      cert[key] = value;
    }

    return cert;
  }

  get id() {
    return this.ip + ':' + this.port + ':' + this.fingerprint;
  }

  static fromElement(element) {
    const cert = new TLSCertificate();

    setProperties(this.parseElement(element), cert);

    return cert;
  }

  static parseElement(element = {}) {
    const {fingerprint} = element;
    return {fingerprint};
  }
}

export default TLSCertificate;

// vim: set ts=2 sw=2 tw=80:
